
/////////////////////////////////////////////////////////////////////////
// G4Tutorial:
//
// PhysicsEMPositronStandard.hh
// 
// Assembling electromagnetic physics processes for positrons.
// 
// The considered processes are G4MultipleScattering, G4eIonisation,
// G4eBremsstrahlung and G4eplusAnnihilation
//
/////////////////////////////////////////////////////////////////////////


#ifndef PHYSICSEMPOSITRONSTANDARD_HH
#define PHYSICSEMPOSITRONSTANDARD_HH

#include "G4VPhysicsConstructor.hh"
#include "globals.hh"


// G4VPhysicsConstructor is the abstract base class for physics constructors:

class PhysicsEMPositronStandard : public G4VPhysicsConstructor {

 public: 
   PhysicsEMPositronStandard(const G4String& name = "Positron-Standard");
   virtual ~PhysicsEMPositronStandard();
  
 

   // G4VPhysicsConstructor has two pure virtual methods which must be 
   // implemented by the user: ConstructParticle and ConstructProcess.
   // Since only physics processes are dealt with here, ConstructParticle
   // is irrelevant and performs no action. ConstructProcess is used to
   // instantiate all physics processes relevant for the considered particle
   // and type of interaction.
   void ConstructParticle() { };
   void ConstructProcess();
};

#endif // PHYSICSEMPOSITRONSTANDARD_HH








