
/////////////////////////////////////////////////////////////////////////
// G4Tutorial:
//
// PhysicsEMPhotonEPDL.cc
// 
// Assembling electromagnetic physics processes for photons.
// 
// The considered processes are G4LowEnergyPhotoElectric, G4LowEnergyCompton
// G4LowEnergyGammaConversion and G4LowEnergyRayleigh
//
/////////////////////////////////////////////////////////////////////////


#include "PhysicsEMPhotonEPDL.hh"
#include "G4ProcessManager.hh"
#include "G4ParticleDefinition.hh"
#include "G4Gamma.hh"
#include "G4LowEnergyCompton.hh"
#include "G4LowEnergyGammaConversion.hh"
#include "G4LowEnergyPhotoElectric.hh"
#include "G4LowEnergyRayleigh.hh"
#include "G4StepLimiter.hh"


PhysicsEMPhotonEPDL::PhysicsEMPhotonEPDL(const G4String& name): 
   G4VPhysicsConstructor(name) {
 
  // Information about physics processes is printed:
  G4cout << "ELECTROMAGNETIC PROCESS(ES): G4LowEnergyPhotoElectric (photon)" 
         << G4endl
         << "                             G4LowEnergyCompton (photon)" 
         << G4endl
         << "                             G4LowEnergyGammaConversion (photon)" 
         << G4endl
         << "                             G4LowEnergyRayleigh (photon)" 
         << G4endl
         << "APPLIED MODEL(S): -" 
         << G4endl;
}


PhysicsEMPhotonEPDL::~PhysicsEMPhotonEPDL() { 

}


void PhysicsEMPhotonEPDL::ConstructProcess() {

  // **************
  // *** Photon ***
  // **************
  
  // The considered physics processes are instantiated:
  G4LowEnergyPhotoElectric* photPhotoElectricProcess = 
                                           new G4LowEnergyPhotoElectric();
  G4LowEnergyCompton* photComptonProcess = new G4LowEnergyCompton();
  G4LowEnergyGammaConversion* photGammaConvProcess = 
                                           new G4LowEnergyGammaConversion();
  G4LowEnergyRayleigh* photRayleighProcess = new G4LowEnergyRayleigh();

  // The step limiter process is instantiated:
  G4StepLimiter* photStepLimiter = new G4StepLimiter();

  // Finally, the processes are added to the particles' process manager:
  G4ParticleDefinition* particle = G4Gamma::Gamma(); 
  G4ProcessManager* processManager = particle -> GetProcessManager();
  processManager -> AddDiscreteProcess(photPhotoElectricProcess);
  processManager -> AddDiscreteProcess(photComptonProcess);
  processManager -> AddDiscreteProcess(photGammaConvProcess);
  processManager -> AddDiscreteProcess(photRayleighProcess);
  processManager -> AddDiscreteProcess(photStepLimiter);
}
